"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguageServiceValidator = void 0;
const LanguageServiceFeatures_cjs_1 = require("./LanguageServiceFeatures.cjs");
const TypeScriptTransformerBase_cjs_1 = require("../Transformation/TypeScriptTransformerBase.cjs");
/**
 * Provides the functionality to validate files for a language service.
 */
class LanguageServiceValidator extends TypeScriptTransformerBase_cjs_1.TypeScriptTransformerBase {
    /**
     * Initializes a new instance of the {@linkcode LanguageServiceValidator} class.
     *
     * @param tsLibrary
     * The TypeScript library.
     */
    constructor(tsLibrary) {
        super(new LanguageServiceFeatures_cjs_1.LanguageServiceFeatures(tsLibrary));
    }
    /**
     * Validates the specified {@linkcode sourceFile}.
     *
     * @param sourceFile
     * The file to validate.
     *
     * @param compilerOptions
     * The options of the compilation.
     *
     * @returns
     * The issues in the specified {@linkcode sourceFile}.
     */
    Validate(sourceFile, compilerOptions) {
        var _a;
        let context = { diagnostics: [] };
        this.Features.TypeScript.transform(sourceFile, [this.GetFactory(context)], compilerOptions);
        return (_a = context.diagnostics) !== null && _a !== void 0 ? _a : [];
    }
    /**
     * Transforms the specified {@linkcode node}.
     *
     * @param node
     * The node to transform.
     *
     * @param context
     * The context of the operation.
     *
     * @param tsContext
     * The context of the typescript transformation.
     *
     * @returns
     * The transformed representation of the specified {@linkcode node}.
     */
    VisitNode(node, context, tsContext) {
        super.VisitNode(node, context, tsContext);
        return node;
    }
}
exports.LanguageServiceValidator = LanguageServiceValidator;
//# sourceMappingURL=LanguageServiceValidator.cjs.map