import ts from "typescript";
import { LanguageServiceFeatures } from "./LanguageServiceFeatures.cjs";
import { ITypeScriptContext } from "../Transformation/ITypeScriptContext.cjs";
import { TypeScriptTransformerBase } from "../Transformation/TypeScriptTransformerBase.cjs";
/**
 * Provides the functionality to validate files for a language service.
 */
export declare class LanguageServiceValidator extends TypeScriptTransformerBase<LanguageServiceFeatures> {
    /**
     * Initializes a new instance of the {@linkcode LanguageServiceValidator} class.
     *
     * @param tsLibrary
     * The TypeScript library.
     */
    constructor(tsLibrary: typeof ts);
    /**
     * Validates the specified {@linkcode sourceFile}.
     *
     * @param sourceFile
     * The file to validate.
     *
     * @param compilerOptions
     * The options of the compilation.
     *
     * @returns
     * The issues in the specified {@linkcode sourceFile}.
     */
    Validate(sourceFile: ts.SourceFile, compilerOptions?: ts.CompilerOptions): ts.Diagnostic[];
    /**
     * Transforms the specified {@linkcode node}.
     *
     * @param node
     * The node to transform.
     *
     * @param context
     * The context of the operation.
     *
     * @param tsContext
     * The context of the typescript transformation.
     *
     * @returns
     * The transformed representation of the specified {@linkcode node}.
     */
    protected VisitNode<T extends ts.Node>(node: T, context: ITypeScriptContext, tsContext: ts.TransformationContext): T;
}
